OC.L10N.register(
    "mail",
    {
    "Mail" : "Correu electrónic",
    "Loading accounts" : "S'està carregant",
    "Error while loading the accounts." : "Error al carregar els comptes.",
    "Can not load this folder." : "No s'ha pogut carregar aquesta carpeta.",
    "Searching for {query}" : "Buscant per {query}",
    "Error while deleting message." : "Error en esborrar el missatge.",
    "Forwarded message" : "Missatge respost",
    "Choose a folder to store the attachment in" : "Esculli una carpeta per guardar el arxiu adjunt",
    "Attachments saved to Files." : "Arxius adjunts guardats a Fitxers.",
    "Attachment saved to Files." : "Arxiu adjunt guardat a Fitxers.",
    "Error while saving attachments to Files." : "Error en guardar els arxius adjunts a Fitxers.",
    "Error while saving attachment to Files." : "Error al guardar l'arxiu adjunt a Fitxers.",
    "Message flag could not be set." : "No s'ha pogut assignar l'etiqueta al missatge.",
    "Could not move message." : "No es pot moure el missatge",
    "Invalid account" : "Compte invàlid",
    "Invalid folder" : "Directori invàlid",
    "Error while creating the account: " : "Error al crear el compte:",
    "Unknown error" : "Error desconegut",
    "All inboxes" : "Totes les safates d'entrada",
    "you" : "Tu",
    "Send message to {email}" : "Envia missatge per {email}",
    "Could not load {tag}{name}{endtag}" : "No s'ha pogut carregar {tag}{name}{endtag}",
    "There was a problem loading {tag}{name}{endtag}" : "Hi ha hagut un problema al carregar {tag}{name}{endtag}",
    "{from}\n{subject}" : "{from}\n{subject}",
    "Nextcloud Mail" : "Nextcloud correo",
    "Save" : "Desa",
    "Show all folders" : "Mostra totes les carpetes",
    "Collapse folders" : "Redueix les carpetes",
    "Error while deleting account." : "Error al borrar el compte",
    "Choose a file to add as attachment" : "Escull un fitxer per adjuntar al correu",
    "An error occurred while uploading {fname}" : "S'ha produït un error",
    "Reply" : "Respon",
    "Send" : "Envia",
    "Sending …" : "Enviant...",
    "Message sent!" : "Missatge enviat!",
    "Server error" : "Error del servidor",
    "An unknown error occurred" : "S\\'ha produït un error desconegut",
    "Opening HTML drafts is not supported yet." : "Encara no està permès obrir esborranys en HTML.",
    "No writable calendars found" : "No s'han trobat calendaris editables",
    "Error while importing the calendar event" : "Error al importar l'esdeveniment de calendari",
    "Error while downloading calendar event" : "Error al carregar l'esdeveniment de calendari",
    "& others" : "& altres",
    "Error while loading messages." : "Error al carregar els missatges",
    "Error while refreshing messages." : "Error al carregar els missatges",
    "Setting up your account" : "Configurant el teu compte",
    "Inbox" : "Safata d'Entrada",
    "Sent" : "Enviat",
    "Drafts" : "Esborranys",
    "Archive" : "Arxiu",
    "Trash" : "Esborra",
    "Junk" : "Brossa",
    "All" : "Tots",
    "Favorites" : "Preferits",
    "Auto detect failed. Please use manual mode." : "Detecció automatica fallida. Siusplau, utilitzi el mode manual.",
    "Creating account failed: " : "La creació del compte ha fallat:",
    "Delete permanently" : "Esborra permanentment",
    "Error loading message" : "Error al carregar el missatge",
    "Settings" : "Configuració",
    "Forwarding to %s" : "Reenviant a %s",
    "Click here if you are not automatically redirected within the next few seconds." : "Prem aquí si no se't redirigeix automàticament en pocs segons.",
    "Redirect" : "Redireccionar",
    "The link leads to %s" : "L'enllaç dirigeix a %s",
    "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Si no vols visitar aquella pàgina, pots tornar a <a href=\"%s\">Mail</a>.",
    "Continue to %s" : "Continua a %s",
    "Delete account" : "Esborra el compte",
    "Try again" : "Torna a provar",
    "New message" : "Nou missatge",
    "Account Settings" : "Paràmetres del compte",
    "Aliases" : "Àlies",
    "Mail address" : "Adreça de correu",
    "Display Name" : "Nom d'usuari",
    "Keyboard shortcuts" : "Dreceres de teclat",
    "Speed up your Mail experience with these quick shortcuts." : "Accelera el teu us de Mail amb aquestes dreceres de teclat.",
    "Compose new message" : "Nou missatge",
    "Newer message" : "Missatges més nous",
    "Older message" : "Missatges més vells",
    "Toggle star" : "Commuta l'estrella",
    "Toggle unread" : "Commuta la lectura",
    "Delete" : "Esborra",
    "Search" : "Cerca",
    "Refresh" : "Refresca",
    "Connect your mail account" : "Connecteu el teu compte de correu",
    "Name" : "Nom",
    "Mail Address" : "Adreça de correu",
    "Password" : "Contrasenya",
    "Manual configuration" : "Manual de la configuració",
    "IMAP Host" : "IMAP Host",
    "IMAP security" : "IMAP security",
    "None" : "Cap",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "Port IMAP",
    "IMAP User" : "Usuari IMAP",
    "IMAP Password" : "Contrasenya IMAP",
    "SMTP Host" : "Host SMTP",
    "SMTP security" : "security SMTP",
    "SMTP Port" : "Port SMTP",
    "SMTP User" : "Usuari SMTP",
    "SMTP Password" : "Contrasenya SMTP",
    "Connect" : "Connecta",
    "from" : "des de",
    "to" : "a",
    "cc" : "cc",
    "bcc" : "bcc",
    "Subject" : "Assumpte",
    "Save all to Files" : "Desa tots els fitxers",
    "Add mail account" : "Afegeix compte de correu",
    "No search results for" : "No s'han trobat cap resultat",
    "The images have been blocked to protect your privacy." : "S'han bloquejat les imatges per protegir la teva privacitat.",
    "Show images from this sender" : "Mostra imatges d'aquest remitent",
    "Forward" : "Respondre",
    "Import into calendar" : "Importar al calendari",
    "Download attachment" : "Descarrega l'adjunt",
    "Save to Files" : "Desa els fitxers"
},
"nplurals=2; plural=(n != 1);");
